==> jc-1.4.0.tar.gz: javax/imageio/metadata/IIONodeList.h <==
// class javax.imageio.metadata.IIONodeList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 929407d973c5ea3f javax_imageio_metadata_IIONodeList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_metadata_IIONodeList_H_
#define _JC_javax_imageio_metadata_IIONodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_javax_imageio_metadata_IIONodeList$sub_refs	_jc_javax_imageio_metadata_IIONodeList$sub_refs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$sub_nonrefs	_jc_javax_imageio_metadata_IIONodeList$sub_nonrefs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$refs	_jc_javax_imageio_metadata_IIONodeList$refs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$nonrefs	_jc_javax_imageio_metadata_IIONodeList$nonrefs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$object	_jc_javax_imageio_metadata_IIONodeList$object;

typedef const struct _jc_javax_imageio_metadata_IIONodeList$vmethods	_jc_javax_imageio_metadata_IIONodeList$vmethods;
typedef const struct _jc_javax_imageio_metadata_IIONodeList$vtable	_jc_javax_imageio_metadata_IIONodeList$vtable;
typedef const struct _jc_javax_imageio_metadata_IIONodeList$vtype	_jc_javax_imageio_metadata_IIONodeList$vtype;

// Constructors
extern void _jc_javax_imageio_metadata_IIONodeList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *);

// Virtual methods
extern jint _jc_javax_imageio_metadata_IIONodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *);
extern struct _jc_object *_jc_javax_imageio_metadata_IIONodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *, jint);
extern void _jc_javax_imageio_metadata_IIONodeList$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_metadata_IIONodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_javax_imageio_metadata_IIONodeList$method_info$item$768348a8778b0a3e;
extern _jc_method _jc_javax_imageio_metadata_IIONodeList$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_imageio_metadata_IIONodeList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *);
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *);
};

// Vtable
struct _jc_javax_imageio_metadata_IIONodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_metadata_IIONodeList$vmethods	javax_imageio_metadata_IIONodeList;
};

// Vtype
struct _jc_javax_imageio_metadata_IIONodeList$vtype {
	_jc_type			type;
	_jc_javax_imageio_metadata_IIONodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIONodeList$sub_refs {
	struct _jc_object	*children;
};

// Reference instance fields (object)
struct _jc_javax_imageio_metadata_IIONodeList$refs {
    _jc_javax_imageio_metadata_IIONodeList$sub_refs	javax_imageio_metadata_IIONodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIONodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_metadata_IIONodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_metadata_IIONodeList$sub_nonrefs	javax_imageio_metadata_IIONodeList;
};

// Object instance structure
struct _jc_javax_imageio_metadata_IIONodeList$object {
	_jc_javax_imageio_metadata_IIONodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_metadata_IIONodeList$vtype	*vtype;
	_jc_javax_imageio_metadata_IIONodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_metadata_IIONodeList$vtype _jc_javax_imageio_metadata_IIONodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_metadata_IIONodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_metadata_IIONodeList$class_object;

#endif	/* _JC_javax_imageio_metadata_IIONodeList_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/metadata/IIONodeList.h <==
// class javax.imageio.metadata.IIONodeList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 929407d973c5ea3f javax_imageio_metadata_IIONodeList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_metadata_IIONodeList_H_
#define _JC_javax_imageio_metadata_IIONodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_javax_imageio_metadata_IIONodeList$sub_refs	_jc_javax_imageio_metadata_IIONodeList$sub_refs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$sub_nonrefs	_jc_javax_imageio_metadata_IIONodeList$sub_nonrefs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$refs	_jc_javax_imageio_metadata_IIONodeList$refs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$nonrefs	_jc_javax_imageio_metadata_IIONodeList$nonrefs;
typedef struct _jc_javax_imageio_metadata_IIONodeList$object	_jc_javax_imageio_metadata_IIONodeList$object;

typedef const struct _jc_javax_imageio_metadata_IIONodeList$vmethods	_jc_javax_imageio_metadata_IIONodeList$vmethods;
typedef const struct _jc_javax_imageio_metadata_IIONodeList$vtable	_jc_javax_imageio_metadata_IIONodeList$vtable;
typedef const struct _jc_javax_imageio_metadata_IIONodeList$vtype	_jc_javax_imageio_metadata_IIONodeList$vtype;

// Constructors
extern void _jc_javax_imageio_metadata_IIONodeList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_imageio_metadata_IIONodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_imageio_metadata_IIONodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_metadata_IIONodeList$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_metadata_IIONodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_javax_imageio_metadata_IIONodeList$method_info$item$768348a8778b0a3e;
extern _jc_method _jc_javax_imageio_metadata_IIONodeList$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_imageio_metadata_IIONodeList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_imageio_metadata_IIONodeList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_metadata_IIONodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_metadata_IIONodeList$vmethods	javax_imageio_metadata_IIONodeList;
};

// Vtype
struct _jc_javax_imageio_metadata_IIONodeList$vtype {
	_jc_type			type;
	_jc_javax_imageio_metadata_IIONodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIONodeList$sub_refs {
	struct _jc_object	*children;
};

// Reference instance fields (object)
struct _jc_javax_imageio_metadata_IIONodeList$refs {
    _jc_javax_imageio_metadata_IIONodeList$sub_refs	javax_imageio_metadata_IIONodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIONodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_metadata_IIONodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_metadata_IIONodeList$sub_nonrefs	javax_imageio_metadata_IIONodeList;
};

// Object instance structure
struct _jc_javax_imageio_metadata_IIONodeList$object {
	_jc_javax_imageio_metadata_IIONodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_metadata_IIONodeList$vtype	*vtype;
	_jc_javax_imageio_metadata_IIONodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_metadata_IIONodeList$vtype _jc_javax_imageio_metadata_IIONodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_metadata_IIONodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_metadata_IIONodeList$class_object;

#endif	/* _JC_javax_imageio_metadata_IIONodeList_H_ */
